@@ -10,6 +10,8 @@ from typing import List, Literal
 import boto3
 from botocore.exceptions import ClientError
 from pydantic import BaseModel
+from pydantic import main
+from pydantic.dataclasses import dataclass
 
 log = logging.getLogger(__name__)
 
@@ -62,7 +64,8 @@ class Evaluation(BaseModel):
         return annotation_string
 
 
-class ComplianceType(BaseModel):
+@dataclass
+class ComplianceType():
     compliant: str = 'COMPLIANT'
     non_compliant: str = 'NON_COMPLIANT'
     not_applicable: str = 'NOT_APPLICABLE'
